django-admin-exporter
=====================

Simple admin actions to download/export selected items in CSV, JSON, XML, etc.

Build Status
------------

[![Build Status](https://travis-ci.org/RyanBalfanz/django-admin-exporter.png?branch=master)](https://travis-ci.org/RyanBalfanz/django-admin-exporter)
[![Build Status](https://travis-ci.org/RyanBalfanz/django-admin-exporter.png?branch=develop)](https://travis-ci.org/RyanBalfanz/django-admin-exporter)

Install
-------

	pip install django-admin-exporter

	Add ``admin_exporter`` to your INSTALLED_APPS.

	Add the vairous exporter actions to individual models or site-wide. See the example project for details.

Running the tests
-----------------

	make test
